
History
========




release/0.1.1 (2016-04-28 17:35:34 -0500)
-----------------------------------------
::

   git log --reverse --pretty=format:'* %s [%h]' v0.1.0..release/0.1.1

* MRG: Merge tag 'vv0.1.0' into develop [dc7d3e6]
* DOC: setup.py: PyPI trove classifiers [1e948a2]
* BLD: setup.cfg: [wheel] universal=1 (py2.py3) [e2a35e9]
* DOC: setup.py, __init__.py: v0.1.1 [7f3239a]


v0.1.0 (2016-04-28 17:15:48 -0500)
----------------------------------
::

   git log --reverse --pretty=format:'* %s [%h]' b8d13ce..v0.1.0

* initial commit [2defc31]
* 2nd commit [c05ab84]
* now it is a package [0993866]
* fixed __init__ and readme [2f1171e]
* Update README.md [f78735d]
* Update jinja_tornado.py [6df0211]
* Update README.md [01fa568]
* REF: README.md -> README.rst [49927dd]
* BLD,DOC: Makefile, README.rst, requirements.txt, setup.py: v0.1.0 packaging [d96bdf3]
* DOC,BLD: HISTORY.rst, setup.py: add HISTORY.rst to long_description [4fbcb84]
* DOC: README.rst: Authors [3f8dd1a]
* DOC: setup.py: author, author_email, url [10e837a]
* DOC: LICENSE: amend (MIT) LICENSE copyright [0e6641a]
* BLD: MANIFEST.in: add MANIFEST.in [746358b]
* BLD: Makefile: 'python setup.py check -r -s' [d196959]
* DOC: HISTORY.rst: `git-changelog.py -r release/v0.1.0 --hdr=- | pbcopy` [824a131]
* BLD: Makefile, requirements[-dev].txt: development requirements [54113b5]
* BLD: Makefile: twine register because HTTPS [c4d1535]
* DOC: HISTORY.rst: `git-changelog.py -r release/v0.1.0 --hdr=- | pbcopy` [e3b7d82]
* MRG: Merge branch 'release/v0.1.0' [bf83680]

